const waitUntil = require('wait-until');
const portscanner = require('portscanner');
const superagent = require('superagent');
const ip = require('ip');
const logger = require('../src/logging');
const CronJob = require('cron').CronJob;

let my_ip = ip.address();
let is_running = false;
let controller_port_open;

let start = async (controller_url, webserver_port, current_service) => {

    if(is_running)
        return false;

    waitUntil()
        .interval(5000)
        .times(1000)
        .condition(
            () => {

                is_running = true;

                let host = controller_url.split('//')[1].split(':')[0];
                let port = controller_url.split('//')[1].split(':')[1];

                portscanner.checkPortStatus(port,host, (error, status) => {

                    if(error)
                        logger.info(error);

                    if(status === 'open'){
                        controller_port_open = true;
                    }else{
                        controller_port_open = false;
                    }

                });
                return controller_port_open;
            }
        )
        .done((result) => {

            is_running = false;

            superagent.post(controller_url+ '/register/service')
                .send({
                    "name": current_service,
                    "ip": my_ip,
                    "port": webserver_port
                })
                .set('Accept', 'application/json')
                .then((res) => {
                    if(res.body.state === 'created'){
                        logger.info('Registration success ' + res.body.state);
                    }
                }).catch(logger.error);
        });
};

let setup = async (controller_url, webserver_port, current_service) => {
    (new CronJob('*/10 * * * * *', async () => {
        await start(controller_url, webserver_port, current_service);
    }, null, true, 'Europe/Berlin')).start();
}

module.exports = {
    start: start,
    setup: setup
}
